function [pid, pt] = replotHtDiff(pid, pt, region)
% function [pid, pt] = replotHtDiff(pid, pt, region)
% 
% when datafile has been previously read in,
% use this function to plot differential orthometric heights onto
% regional basemap; activates tooltip window to describe
% point information (PID, lat/lon, etc)
% 
% pid and pt are both input and output because 'pt' may be
% altered by inclusion of elimPtFile
% 
% input/output:
%   pid     name of point (cell array)
%   pt      dimensions (#piddat x 4)
%         1-2 lat/long (deg)
%         3   ortho height at first datum (m)
%         4   differential ortho height (m)
% input:
%   region          name of geographic region, see 'drawBoundaries'
%                     for list of regions

VERTCONpath;
barmap = 'hsv';

figure
drawBoundaries(region);

% plot the points
scatter(pt(:,2)-360, pt(:,1),[],pt(:,4),'filled');
colormap(barmap)
colorbar
%%linkdata on
axis equal
grid on
%title(fname);
% xlabel('E long (deg)');
% ylabel('N lat (deg)');

% turn on PID labels using datacursor
hdt = datacursormode;
set(hdt,'DisplayStyle','window');
% Declare a custom datatip update function 
% to display PID:
set(hdt,'UpdateFcn',{@labelPIDh,[pt(:,2)-360, pt(:,[1 3 4])], pid})

% http://www.mathworks.com/matlabcentral/answers/95968-how-can-i-set-the-text-font-style-of-a-data-cursor-object
% alldatacursors = findall(gcf,'type','hggroup');
% set(alldatacursors, 'fontsize',14);

return
